@@ -754,29 +754,23 @@ gtk_clue_hunter_do_popup (GtkClueHunter *clue_hunter)
   
   gdk_window_get_origin (clue_hunter->entry->window, &x, &y);
   gdk_window_get_size (clue_hunter->entry->window, &width, &height);
-  
-#if 0
-  if (widget->requisition.height > gdk_screen_height () - (y + height))
-    {
-      if (y + height / 2 > gdk_screen_height () / 2)
-	{
-	  height = MIN (y, widget->requisition.height);
-	  gtk_widget_set_uposition (widget, x, y - height);
-	  gtk_widget_set_usize (widget, width, height);
-	}
-      else
-	{
-	  gtk_widget_set_uposition (widget, x, y + height);
-	  gtk_widget_set_usize (widget, width, gdk_screen_height () - y - height);
-	}
-    }
-  else
-    {
-      gtk_widget_set_uposition (widget, x, y + height);
-      gtk_widget_set_usize (widget, width, 0);
-    }
-#endif
 
+  height = MIN (height, gdk_screen_height ());
+  if (y < 0)
+    {
+      height = MAX (0, height + y);
+      y = 0;
+    }
+  else if (y > gdk_screen_height ())
+    {
+      height = 0;
+      y = gdk_screen_height ();
+    }
+  else if (y + height > gdk_screen_height ())
+    height = gdk_screen_height () - y;
+  width = MIN (width, gdk_screen_width ());
+  x = CLAMP (x, 0, gdk_screen_width () - width);
+  
   if (widget->requisition.height > gdk_screen_height () - (y + height))
     {
       if (y + height / 2 > gdk_screen_height () / 2)
